# -*- coding: utf-8 -*-

from __future__ import unicode_literals

from django.conf import settings
from django.forms import ModelForm
from django.utils.translation import ugettext_lazy as _

from .fields import MultiEmailField
from .models import Contact, ContactFormSettings

if 'captcha' in settings.INSTALLED_APPS:
    from captcha.fields import ReCaptchaField
else:
    ReCaptchaField = None


class ContactForm(ModelForm):
    error_css_class = 'error'
    required_css_class = 'required'

    if ReCaptchaField:
        captcha = ReCaptchaField(attrs={'theme': 'clean'})

    class Meta:
        model = Contact
        fields = [
            'civility',
            'first_name',
            'last_name',
            'email',
            'message',
            'phone',
            'company',
            'city',
            'state',
            'country',
            'optin_newsletter',
        ]
        if ReCaptchaField:
            fields.append('captcha')


class ContactFormSettingsForm(ModelForm):
    email_to = MultiEmailField(
        _("Send mail to"),
        help_text=_(
            "You can specify multiple mail addresses: "
            "Separate them with a comma.")
    )

    class Meta:
        model = ContactFormSettings
        fields = [
            "site",
            "subject",
            "email_to",
            "email_from",
            "success_html",
        ]
