# -*- coding: utf-8 -*-

from django.core.mail import EmailMultiAlternatives
from django.template.loader import render_to_string

from emencia_contact_form.models import ContactFormSettings


class ContactMail(object):
    body_template = 'contact_form/mails/contact_form_message_body.txt'
    body_html_template = 'contact_form/mails/contact_form_message_body.html'

    def __init__(self, body_template=None, body_html_template=None):
        self.body_template = body_template or self.__class__.body_template
        self.body_html_template = body_html_template or self.__class__.body_html_template

    def get_email(self, site, contact, **extra):
        context = {
            'site': site,
            'contact': contact,
            'mail_settings': ContactFormSettings.on_site.get(),
        }
        context.update(extra)
        message = EmailMultiAlternatives(
            self.render_subject(context),
            self.render_body(context),
            self.get_from_email_address(context),
            self.get_to_email_addresses(context),
        )
        message.attach_alternative(self.render_body_html(context), 'text/html')
        return message

    def render_subject(self, context):
        return context['mail_settings'].subject.replace('\n', ' ')

    def render_body(self, context):
        return render_to_string(self.body_template, context)

    def render_body_html(self, context):
        return render_to_string(self.body_html_template, context)

    def get_from_email_address(self, context):
        return context['mail_settings'].email_from or context['contact'].email

    def get_to_email_addresses(self, context):
        return context['mail_settings'].get_to_email_addresses()
